<?xml version="1.0" encoding="ISO-8859-1"?>
<!--XSL file that transforms an Ant target execution XML log file into an HTML documentation-->
<!--This tranformation is part of AntDoc-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method="html" indent="yes" standalone="yes" encoding="ISO-8859-1"/>
	<xsl:template match="/build">
		<html>
			<head>
				<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"/>
				<title>Report concerning an Ant target execution</title>
			</head>
			<body bgcolor="white">
				<h1>Ant target execution report</h1>
				<xsl:call-template name="_print_statistics"/>
				<xsl:call-template name="_print_result"/>
				<xsl:call-template name="_print_warning_messages"/>
				<xsl:call-template name="_print_top_messages"/>
				<h2>Targets<table border="1" cellpadding="0" cellspacing="0">
						<xsl:for-each select="target">
							<xsl:apply-templates select="."/>
						</xsl:for-each>
					</table>
				</h2>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="target">
		<tr>
			<td>
				<table border="1" cellpadding="0" cellspacing="0">
					<tr>
						<td border="1" bgcolor="#C8C8FF">
							<code>
								<xsl:value-of select="@name"/>
							</code>
							<br/>
							<xsl:value-of select="@time"/>
						</td>
						<td border="1">
							<table cellpadding="0" cellspacing="0">
								<xsl:for-each select="task">
									<xsl:apply-templates select="."/>
								</xsl:for-each>
							</table>
						</td>
					</tr>
				</table>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="task">
		<tr>
			<td bgcolor="#D8D8FF">
				<font size="-1">
					<code>
						<xsl:value-of select="@name"/>
					</code>
					<br/>
					<xsl:value-of select="@time"/>
					<br/>
					<code>
						<xsl:value-of select="@location"/>
					</code>
				</font>
			</td>
			<td>
				<table cellpadding="0" cellspacing="0">
					<xsl:for-each select="target | message">
						<xsl:apply-templates select="."/>
					</xsl:for-each>
				</table>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="message">
		<tr>
			<td bgcolor="#E8E8FF">
				<font size="-2">
					<xsl:choose>
						<xsl:when test='@priority = "verbose"'>
							<xsl:attribute name="color">#606060</xsl:attribute>
						</xsl:when>
						<xsl:when test='@priority = "debug"'>
							<xsl:attribute name="color">#808080</xsl:attribute>
						</xsl:when>
						<xsl:when test='@priority = "warn"'>
							<xsl:attribute name="color">#FF8040</xsl:attribute>
						</xsl:when>
						<xsl:when test='@priority = "error"'>
							<xsl:attribute name="color">#804000</xsl:attribute>
						</xsl:when>
						<xsl:when test='@priority = "fatal"'>
							<xsl:attribute name="color">#FF0000</xsl:attribute>
						</xsl:when>
					</xsl:choose>
					<xsl:value-of select="."/>
				</font>
			</td>
		</tr>
	</xsl:template>
	<!--Prints the statistics concerning the Ant target execution-->
	<xsl:template name="_print_statistics">
		<h2>Statistics</h2>
		<xsl:value-of select="count(target)"/> target<xsl:if test="count(target) > 1">s</xsl:if> executed in <xsl:value-of select="@time"/>
	</xsl:template>
	<!--Prints the result concerning the Ant target execution-->
	<xsl:template name="_print_result">
		<h2>Result</h2>
		<xsl:if test="@error">
			<b>
				<font color="#FF0000" size="+1">
					<dl>BUILD FAILED<dd>
							<pre>
								<xsl:choose>
									<xsl:when test="stacktrace">
										<xsl:value-of select="stacktrace"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="@error"/>
									</xsl:otherwise>
								</xsl:choose>
							</pre>
						</dd>
					</dl>
				</font>
			</b>
		</xsl:if>
		<xsl:if test="count(@error) = 0">
			<b>
				<font color="#008000" size="+1">
					<dl>BUILD SUCCESSFUL</dl>
				</font>
			</b>
		</xsl:if>
	</xsl:template>
	<!--Prints the top messages that were output during the Ant target execution-->
	<xsl:template name="_print_top_messages">
		<xsl:if test="count(message) > 0">
			<h2>Top messages<table border="1" cellpadding="0" cellspacing="0">
					<xsl:for-each select="message">
						<xsl:apply-templates select="."/>
					</xsl:for-each>
				</table>
			</h2>
		</xsl:if>
	</xsl:template>
	<!--Prints the warning messages yielded during the Ant target execution-->
	<xsl:template name="_print_warning_messages">
		<xsl:if test='count(//message[@priority = "warn"]) > 0'>
			<h2>Warning messages<table border="1" cellpadding="0" cellspacing="0">
					<xsl:for-each select='//message[@priority = "warn"]'>
						<xsl:apply-templates select="."/>
					</xsl:for-each>
				</table>
			</h2>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
